@@ -1,4 +1,4 @@
-package Pcore::Nginx v1.6.5;
+package Pcore::Nginx v1.6.6;
 
 use Pcore -dist, -class;
 
@@ -36,7 +36,7 @@ sub _build_vhost_dir ($self) {
 sub run ($self) {
 
     # generate mime types
-    my $mime_types = P->cfg->load( $ENV->{share}->get('data/mime.json') )->{suffix};
+    my $mime_types = P->cfg->read( $ENV->{share}->get('data/mime.json') )->{suffix};
 
     my $nginx_mime_types;
 
